@@ -11,3 +11,7 @@ from .statusbar import _StatusBar as StatusBar
 
 from .progressbar import _ProgressBar as ProgressBar
 from .progressbar import _ProgressBarStyle as ProgressBarStyle
+
+from .column import _Column as Column
+
+from .main_window import _MainWindow as MainWindow
